defmodule GroupB.StageNote do
  require Logger

  alias GroupB.Components.StageNote, as: StageNoteC

  def print_stage_notes(player) do
    notes = get_stage_notes(player)
    Logger.info("Set up player #{player}, some notes:")

    for note <- notes do
      # Logger.info("#{inspect(note, pretty: true)}")
      Logger.info(gen_pace_note(note))
    end
  end

  def gen_pace_note(%{max_speed: 10, type: :left}), do: "flat left"
  def gen_pace_note(%{max_speed: 10, type: :right}), do: "flat right"
  def gen_pace_note(%{type: :right} = note), do: "#{maybe_to_int(note[:max_speed])} right"
  def gen_pace_note(%{type: :left} = note), do: "#{maybe_to_int(note[:max_speed])} left"

  def gen_pace_note(%{type: :straight} = note) do
    cond do
      note[:distance] <= 10 ->
        "and short"

      note[:distance] <= 20 ->
        "into"

      true ->
        "#{maybe_to_int(note[:distance])}"
    end
  end

  def gen_pace_note(%{type: :esses, req_focus: focus} = note) do
    if focus > 5 do
      "caution, winding"
    else
      "winding"
    end
  end

  @doc "Get an ordered list of stage notes for a given player entity"
  def get_stage_notes(player) do
    stages = StageNoteC.Player.search(player)

    unsorted =
      for stage_id <- stages do
        %{
          idx: StageNoteC.OrderIndex.get_one(stage_id),
          type: StageNoteC.Type.get_one(stage_id),
          active: StageNoteC.Active.exists?(stage_id),
          max_speed: StageNoteC.MaxSpeed.get_one(stage_id, 0),
          distance: StageNoteC.Distance.get_one(stage_id, 0),
          req_focus: StageNoteC.RequiredFocus.get_one(stage_id, 0)
        }
      end

    unsorted |> Enum.sort_by(&Map.get(&1, :idx))
  end

  def maybe_to_int(float) do
    truncated = trunc(float)
    if truncated == float, do: truncated, else: float
  end
end
