defmodule GroupB.Systems.ClientEventHandler do
  @moduledoc """
  Documentation for ClientEventHandler system.
  """
  @behaviour ECSx.System

  alias GroupB.Components.Player
  alias GroupB.Components.StageNote

  require Logger

  def num_stages, do: 10

  @impl ECSx.System
  def run do
    client_events = ECSx.ClientEvents.get_and_clear()

    Enum.each(client_events, &process_one/1)
    :ok
  end

  defp process_one({player, :setup}) do
    Player.Speed.add(player, 0.0)
    Player.Throttle.add(player, 0.0)
    Player.Focus.add(player, 0.0)
    Player.StageTime.add(player, 0.0)

    setup_stage(player)
    setup_actions(player)

    GroupB.StageNote.print_stage_notes(player)
    :ok
  end

  defp setup_stage(player) do
    # we use a reduction here so that the last stagenote type can be
    # piped in to setup_one_stage_note/3, which goes further in to the
    # weighted picked to remove straights from future weightings to
    # prevent multiple straights from happening back-to-back
    Enum.reduce(
      1..num_stages(),
      {nil, :straight},
      fn idx, {_note_id, last_type} ->
        setup_one_stage_note(player, idx, last_type)
      end
    )
  end

  defp setup_one_stage_note(player, idx, last_type) do
    note_id = "#{player}/sn/#{idx}"

    StageNote.OrderIndex.add(note_id, idx)
    StageNote.Player.add(note_id, player)

    type = GroupB.SeedData.one_weighted_note_type(last_type)
    StageNote.Type.add(note_id, type)

    case type do
      :straight ->
        distance = GroupB.SeedData.one_weighted_speed() * 10
        StageNote.Distance.add(note_id, distance)

      :esses ->
        distance = GroupB.SeedData.one_weighted_speed() * 10
        StageNote.Distance.add(note_id, distance)
        StageNote.RequiredFocus.add(note_id, 2 * distance / 10)

      _ ->
        max_speed = GroupB.SeedData.one_weighted_speed()
        StageNote.MaxSpeed.add(note_id, max_speed)
        StageNote.RequiredFocus.add(note_id, 10 - max_speed)
    end

    {note_id, type}
  end

  defp setup_actions(player) do
  end

  # defp process_one({_player, _event}) do
  # end
end
